@@ -66,7 +66,7 @@ nice_lm_slopes <- function(model,
                            ci.alternative = "two.sided",
                            ...) {
   rlang::check_installed("effectsize",
-                         version = "0.8.2",
+                         version = get_dep_version("effectsize"),
                          reason = "for this function.")
   if (inherits(model, "list") && all(unlist(lapply(model, inherits, "lm")))) {
     models.list <- model
@@ -164,7 +164,7 @@ nice_lm_slopes <- function(model,
   ))
   table.stats <- table.stats[correct.order, ] # 1, 4, 7, 2, 5, 8, 3, 6, 9
   table.stats <- dplyr::rename(table.stats,
-    `Predictor (+/-1 SD)` = .data$Predictor
+    `Predictor (+/-1 SD)` = "Predictor"
   )
 
   names(table.stats)[names(table.stats) == "b"] <- b.label
