@@ -4,6 +4,10 @@
 #' around the `flextable` package with sensical defaults and
 #' automatic formatting features.
 #'
+#' @details The resulting `flextable` objects can be opened in
+#' Word with `print(table, preview ="docx")`, or saved to
+#' Word with the `flextable::save_as_docx()` function.
+#'
 #' @param data The data frame, to be converted to a flextable.
 #' The data frame cannot have duplicate column names.
 #' @param italics Which columns headers should be italic? Useful
@@ -155,7 +159,7 @@ nice_table <- function(data,
                        note,
                        separate.header) {
   rlang::check_installed(c("flextable", "methods"),
-    version = c("0.9.1", NA),
+    version = c(get_dep_version("flextable"), NA),
     reason = "for this function."
   )
 
@@ -369,9 +373,9 @@ prepare_report <- function(dataframe, report, short) {
     # t.test, aov, and wilcox need to be done separately
     # because they have no model_class attribute
     if ("Method" %in% names(dataframe)) {
-      if (grepl("t-test", dataframe$Method)) {
+      if (all(grepl("t-test", dataframe$Method))) {
         report <- "t.test"
-      } else if (grepl("Wilcox", dataframe$Method)) {
+      } else if (all(grepl("Wilcox", dataframe$Method))) {
         report <- "wilcox"
       }
     } else if ("Sum_Squares" %in% names(dataframe)) {
@@ -416,7 +420,7 @@ prepare_report <- function(dataframe, report, short) {
       if (short == TRUE) {
         dataframe <- select(dataframe, -c("Fit", "95% CI (b)"))
         dataframe <- dataframe[-(
-          which(is.na(dataframe$Parameter)):nrow(dataframe)), ]
+          which(is.na(dataframe$Parameter))[1]:nrow(dataframe)), ]
       }
     } else if (report == "aov") {
       if ("Eta2_CI_low" %in% names(dataframe)) {
